@@ -152,7 +152,7 @@ def initialize_project_dir(project_name, project_path):
     log.info("Generated: %s >>> Done" % dockerfile_file)
 
     # 创建测试数据目录
-    test_data = os.path.join(abs, "test_data")
+    test_data = os.path.join(abs_wrapper_dir, "test_data")
     os.makedirs(test_data,exist_ok=True)
-    test_png = os.path.join(abs, "test_data","test.png")
+    test_png = os.path.join(abs_wrapper_dir, "test_data","test.png")
     shutil.copy(os.path.join(os.path.dirname(aiges.__file__),"test_data","test.png"), test_png)
