@@ -726,11 +726,15 @@ class WrapperBase(metaclass=Metaclass):
             log.error("Please return Response instance in function wrapperOnceExec")
             return False
 
+
         # check 响应list长度
         if len(resp.list) == 0:
             log.error("Please return content in response.list")
             return False
 
+        if resp.error_code != 0:
+            return True
+
         for d in resp.list:
             # check Response data 类型
             if not isinstance(d.data, memoryview) and not isinstance(d.data, bytes):
